package com.dcsoft.system.consume.service.impl;

import com.dcsoft.common.core.utils.DateUtils;
import com.dcsoft.system.consume.domain.ConsumeTenant;
import com.dcsoft.system.consume.mapper.ConsumeTenantMapper;
import com.dcsoft.system.consume.service.IConsumeTenantService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;


/**
 * 商户信息Service业务层处理
 *
 * @author nichun
 * @date 2023-09-15
 */
@Service
public class ConsumeTenantServiceImpl implements IConsumeTenantService
{
    @Autowired
    private ConsumeTenantMapper consumeTenantMapper;

    /**
     * 查询商户信息
     *
     * @param id 商户信息主键
     * @return 商户信息
     */
    @Override
    public ConsumeTenant selectConsumeTenantById(Long id)
    {
        return consumeTenantMapper.selectConsumeTenantById(id);
    }

    /**
     * 查询商户信息列表
     *
     * @param consumeTenant 商户信息
     * @return 商户信息
     */
    @Override
    public List<ConsumeTenant> selectConsumeTenantList(ConsumeTenant consumeTenant)
    {
        return consumeTenantMapper.selectConsumeTenantList(consumeTenant);
    }

    /**
     * 新增商户信息
     *
     * @param consumeTenant 商户信息
     * @return 结果
     */
    @Override
    public int insertConsumeTenant(ConsumeTenant consumeTenant)
    {
        consumeTenant.setCreateTime(DateUtils.getNowDate());
        return consumeTenantMapper.insertConsumeTenant(consumeTenant);
    }

    /**
     * 修改商户信息
     *
     * @param consumeTenant 商户信息
     * @return 结果
     */
    @Override
    public int updateConsumeTenant(ConsumeTenant consumeTenant)
    {
        consumeTenant.setUpdateTime(DateUtils.getNowDate());
        return consumeTenantMapper.updateConsumeTenant(consumeTenant);
    }

    /**
     * 批量删除商户信息
     *
     * @param ids 需要删除的商户信息主键
     * @return 结果
     */
    @Override
    public int deleteConsumeTenantByIds(Long[] ids)
    {
        return consumeTenantMapper.deleteConsumeTenantByIds(ids);
    }

    /**
     * 删除商户信息信息
     *
     * @param id 商户信息主键
     * @return 结果
     */
    @Override
    public int deleteConsumeTenantById(Long id)
    {
        return consumeTenantMapper.deleteConsumeTenantById(id);
    }
}
